@@ -6,7 +6,7 @@ ensembl75 = EnsemblRelease(75)
 
 def test_gene_ids():
     # only load chromosome 1 to speed up tests
-    df = ensembl75.dataframe_for_contig("1")
+    df = ensembl75.dataframe(contig="1")
     assert 'gene_id' in df
     # Ensembl gene ids are formatted like ENSG00000223972
     # which is always length 15
